@@ -3,7 +3,7 @@ package Perl::Unsafe::Signals;
 use strict;
 use XSLoader ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 XSLoader::load 'Perl::Unsafe::Signals', $VERSION;
 
@@ -14,9 +14,23 @@ sub import {
 
 sub UNSAFE_SIGNALS (&) {
     my $code = shift;
-    my $oldflags = push_unsafe_flag();
+    my $restore = Perl::Unsafe::Signals::Restore->new;
     $code->();
-    pop_unsafe_flag( $oldflags );
+}
+
+{
+    package # helper class, hide from PAUSE indexer
+	Perl::Unsafe::Signals::Restore;
+    sub new {
+	my($class) = @_;
+	my $oldflags = Perl::Unsafe::Signals::push_unsafe_flag();
+	bless \$oldflags, $class;
+    }
+    sub DESTROY {
+	my $self = shift;
+	my $oldflags = $$self;
+	Perl::Unsafe::Signals::pop_unsafe_flag($oldflags);
+    }
 }
 
 1;
@@ -61,6 +75,9 @@ run for a long time and for which you want to set a timeout.
 This module therefore allows you to define C<UNSAFE_SIGNALS> blocks
 in which signals will be handled "unsafely".
 
+Note that, no matter how short you make the unsafe block, it will still
+be unsafe. Use with caution.
+
 =head1 NOTES
 
 This module used to be a source filter, but is no longer, thanks to Scott
@@ -68,9 +85,11 @@ McWhirter.
 
 =head1 AUTHOR
 
-Copyright (c) 2005 Rafael Garcia-Suarez. This program is free software; you
+Copyright (c) 2005, 2015 Rafael Garcia-Suarez. This program is free software; you
 may redistribute it and/or modify it under the same terms as Perl itself.
 
+A git repository for the sources is at L<https://github.com/rgs/Perl-Unsafe-Signals>.
+
 =head1 SEE ALSO
 
 L<perlrun>, L<perl581delta>
